@@ -44,7 +44,7 @@ move_resize_window (WnckWindow *win,
 
     if (action_menu_mapped)
     {
-	gtk_object_destroy (GTK_OBJECT (action_menu));
+	gtk_widget_destroy (action_menu);
 	return;
     }
 
@@ -96,7 +96,7 @@ common_button_event (WnckWindow *win,
 	GdkCursor* cursor;
 	cursor = gdk_cursor_new (GDK_LEFT_PTR);
 	gdk_window_set_cursor (d->frame_window, cursor);
-	gdk_cursor_unref (cursor);
+	g_object_unref (cursor);
     }
 
     switch (gtkwd_type) {
@@ -134,7 +134,7 @@ close_button_event (WnckWindow *win,
 
     if (action_menu_mapped && gtkwd_type == GButtonPress)
     {
-	gtk_object_destroy (GTK_OBJECT (action_menu));
+	gtk_widget_destroy (action_menu);
     }
 
     common_button_event (win, gtkwd_event, gtkwd_type,
@@ -161,7 +161,7 @@ max_button_event (WnckWindow *win,
 
     if (action_menu_mapped && gtkwd_type == GButtonPress)
     {
-	gtk_object_destroy (GTK_OBJECT (action_menu));
+	gtk_widget_destroy (action_menu);
     }
 
     if (wnck_window_is_maximized (win))
@@ -220,7 +220,7 @@ min_button_event (WnckWindow *win,
 
     if (action_menu_mapped && gtkwd_type == GButtonPress)
     {
-	gtk_object_destroy (GTK_OBJECT (action_menu));
+	gtk_widget_destroy (action_menu);
     }
 
     common_button_event (win, gtkwd_event, gtkwd_type,
@@ -297,9 +297,7 @@ above_button_event (WnckWindow *win,
     case GButtonRelease:
 	if (gtkwd_event->button == 1)
 	    if (state == BUTTON_EVENT_ACTION_STATE)
-#ifdef HAVE_LIBWNCK_2_18_1
 		wnck_window_make_above (win);
-#endif
 	break;
     default:
 	break;
@@ -365,9 +363,7 @@ unabove_button_event (WnckWindow *win,
     case GButtonRelease:
 	if (gtkwd_event->button == 1)
 	    if (state == BUTTON_EVENT_ACTION_STATE)
-#ifdef HAVE_LIBWNCK_2_18_1
 		wnck_window_unmake_above (win);
-#endif
 	break;
     default:
 	break;
@@ -471,7 +467,7 @@ title_event (WnckWindow       *win,
     {
 	GdkCursor* cursor = gdk_cursor_new (GDK_LEFT_PTR);
 	gdk_window_set_cursor (d->frame_window, cursor);
-	gdk_cursor_unref (cursor);
+	g_object_unref (cursor);
     }
 
     if (gtkwd_type != GButtonPress)
@@ -576,7 +572,7 @@ frame_common_event (WnckWindow       *win,
 	if (cursor)
 	{
 	    gdk_window_set_cursor (d->frame_window, cursor);
-	    gdk_cursor_unref (cursor);
+	    g_object_unref (cursor);
 	}
     }
 
@@ -924,7 +920,8 @@ event_filter_func (GdkXEvent *gdkxevent,
 	{
 	    if (!wnck_window_get (xevent->xcreatewindow.window))
 	    {
-		GdkWindow *toplevel = create_foreign_window (xevent->xcreatewindow.window);
+		gdk_error_trap_push ();
+		GdkWindow *toplevel = gdk_x11_window_foreign_new_for_display (gdkdisplay, xevent->xcreatewindow.window);
 
 		if (toplevel)
 		{
@@ -937,6 +934,7 @@ event_filter_func (GdkXEvent *gdkxevent,
 		    if (get_window_prop (xevent->xcreatewindow.window, select_window_atom, &select))
 			update_switcher_window (xevent->xcreatewindow.window, select);
 		}
+	    gdk_error_trap_pop_ignored ();
 	    }
 	}
 	break;
@@ -1002,7 +1000,7 @@ event_filter_func (GdkXEvent *gdkxevent,
 		 xevent->xproperty.atom == compiz_shadow_color_atom)
 	{
 	    GdkScreen  *g_screen = gdk_display_get_default_screen (gdkdisplay);
-	    Window     root = GDK_WINDOW_XWINDOW (gdk_screen_get_root_window (g_screen));
+	    Window     root = GDK_WINDOW_XID (gdk_screen_get_root_window (g_screen));
 	    WnckScreen *screen;
 
 	    screen = wnck_screen_get_for_root (root);
