@@ -37,38 +37,10 @@
 #include <X11/extensions/Xrender.h>
 #include <X11/Xregion.h>
 
-#ifdef HAVE_GTK_2_24
-
-#ifndef GDK_DISABLE_DEPRECATED
-#define GDK_DISABLE_DEPRECATED
-#endif
-
-#define create_foreign_window(xid)						       \
-    gdk_x11_window_foreign_new_for_display (gdk_display_get_default (),	       \
-					    xid)
-#else
-
-#define create_foreign_window(xid)						       \
-    gdk_window_foreign_new (xid)
-
-#ifdef GDK_DISABLE_DEPRECATED
-#undef GDK_DISABLE_DEPRECATED
-#endif
-
-#endif
-
-#ifndef GTK_DISABLE_DEPRECATED
-#define GTK_DISABLE_DEPRECATED
-#endif
-
 #include <gtk/gtk.h>
 #include <gdk/gdkx.h>
 #include <gdk/gdk.h>
 
-#ifdef USE_GCONF
-#include <gconf/gconf-client.h>
-#endif
-
 #ifdef USE_DBUS_GLIB
 #define DBUS_API_SUBJECT_TO_CHANGE
 #include <dbus/dbus.h>
@@ -77,11 +49,6 @@
 
 #define WNCK_I_KNOW_THIS_IS_UNSTABLE
 #include <libwnck/libwnck.h>
-#include <libwnck/window-action-menu.h>
-
-#ifndef HAVE_LIBWNCK_2_19_4
-#define wnck_window_get_client_window_geometry wnck_window_get_geometry
-#endif
 
 #include <cairo.h>
 #include <cairo-xlib.h>
@@ -109,63 +76,7 @@
 #include <metacity-private/theme.h>
 #endif
 
-#include "gwd-settings-interface.h"
-
-#define METACITY_GCONF_DIR "/apps/metacity/general"
-#define MUTTER_GCONF_DIR "/apps/mutter/general"
-
-#define COMPIZ_USE_SYSTEM_FONT_KEY		    \
-METACITY_GCONF_DIR "/titlebar_uses_system_font"
-		    
-#define COMPIZ_TITLEBAR_FONT_KEY	\
-METACITY_GCONF_DIR "/titlebar_font"
-
-#define COMPIZ_DOUBLE_CLICK_TITLEBAR_KEY	       \
-METACITY_GCONF_DIR "/action_double_click_titlebar"
-
-#define COMPIZ_MIDDLE_CLICK_TITLEBAR_KEY	       \
-METACITY_GCONF_DIR "/action_middle_click_titlebar"
-
-#define COMPIZ_RIGHT_CLICK_TITLEBAR_KEY	       \
-METACITY_GCONF_DIR "/action_right_click_titlebar"
-
-#define MUTTER_DRAGGABLE_BORDER_WIDTH_KEY \
-MUTTER_GCONF_DIR "/draggable_border_width"
-
-#define MUTTER_ATTACH_MODAL_DIALOGS_KEY \
-MUTTER_GCONF_DIR "/attach_modal_dialogs"
-
-#define META_THEME_KEY		\
-METACITY_GCONF_DIR "/theme"
-
-#define META_BUTTON_LAYOUT_KEY		\
-METACITY_GCONF_DIR "/button_layout"
-
-#define GCONF_DIR "/apps/gwd"
-
-#define USE_META_THEME_KEY	    \
-GCONF_DIR "/use_metacity_theme"
-
-#define META_THEME_OPACITY_KEY	        \
-GCONF_DIR "/metacity_theme_opacity"
-
-#define META_THEME_SHADE_OPACITY_KEY	      \
-GCONF_DIR "/metacity_theme_shade_opacity"
-
-#define META_THEME_ACTIVE_OPACITY_KEY	       \
-GCONF_DIR "/metacity_theme_active_opacity"
-
-#define META_THEME_ACTIVE_SHADE_OPACITY_KEY          \
-GCONF_DIR "/metacity_theme_active_shade_opacity"
-
-#define BLUR_TYPE_KEY	   \
-GCONF_DIR "/blur_type"
-
-#define WHEEL_ACTION_KEY   \
-GCONF_DIR "/mouse_wheel_action"
-
-#define USE_TOOLTIPS_KEY \
-GCONF_DIR "/use_tooltips"
+#include <gwd-fwd.h>
 
 #define DBUS_DEST       "org.freedesktop.compiz"
 #define DBUS_PATH       "/org/freedesktop/compiz/decor/screen0"
@@ -225,9 +136,6 @@ WNCK_WINDOW_STATE_MAXIMIZED_VERTICALLY)
 
 #define PROP_MOTIF_WM_HINT_ELEMENTS 3
 
-typedef struct _GWDSettingsWritable GWDSettingsWritable;
-typedef struct _GWDSettingsNotified GWDSettingsNotified;
-
 typedef struct {
 unsigned long flags;
 unsigned long functions;
@@ -395,13 +303,13 @@ typedef struct _decor {
     event_window      button_windows[BUTTON_NUM];
     Box		      *last_pos_entered;
     guint	      button_states[BUTTON_NUM];
-    GdkPixmap	      *pixmap;
-    GdkPixmap	      *buffer_pixmap;
+    Pixmap            x11Pixmap;
+    cairo_surface_t   *surface;
+    cairo_surface_t   *buffer_surface;
     GdkWindow	      *frame_window;
     GtkWidget         *decor_window;
     GtkWidget	      *decor_event_box;
     GtkWidget         *decor_image;
-    GHashTable        *old_pixmaps;
     cairo_t	      *cr;
     decor_layout_t    border_layout;
     decor_context_t   *context;
@@ -417,7 +325,7 @@ typedef struct _decor {
     PangoLayout	      *layout;
     gchar	      *name;
     cairo_pattern_t   *icon;
-    GdkPixmap	      *icon_pixmap;
+    cairo_surface_t   *icon_surface;
     GdkPixbuf	      *icon_pixbuf;
     WnckWindowState   state;
     WnckWindowActions actions;
@@ -473,7 +381,6 @@ extern char *program_name;
 
 /* list of all decorations */
 extern GHashTable    *frame_table;
-extern GHashTable    *destroyed_pixmaps_table;
 
 /* action menu */
 extern GtkWidget     *action_menu;
@@ -784,27 +691,24 @@ cairo_get_shadow (decor_frame_t *, decor_shadow_options_t *opts, gboolean active
 
 /* gdk.c */
 
-void
-gdk_cairo_set_source_color_alpha (cairo_t  *cr,
-				  GdkColor *color,
-				  double   alpha);
-
 GdkWindow *
 create_gdk_window (Window xframe);
 
-GdkColormap *
-get_colormap_for_drawable (GdkDrawable *d);
-
 XRenderPictFormat *
-get_format_for_drawable (decor_t *d, GdkDrawable *drawable);
+get_format_for_surface (decor_t *d, cairo_surface_t *surface);
 
-GdkPixmap *
-create_pixmap (int	 w,
+cairo_surface_t *
+create_surface (int	 w,
 	       int	 h,
 	       GtkWidget *parent_style_window);
 
-GdkPixmap *
-pixmap_new_from_pixbuf (GdkPixbuf *pixbuf, GtkWidget *parent);
+cairo_surface_t *
+create_native_surface_and_wrap (int	  w,
+			       int	  h,
+			       GtkWidget *parent_style_window);
+
+cairo_surface_t *
+surface_new_from_pixbuf (GdkPixbuf *pixbuf, GtkWidget *parent);
 
 /* metacity.c */
 #ifdef USE_METACITY
@@ -1120,15 +1024,6 @@ get_window_prop (Window xwindow,
 unsigned int
 get_mwm_prop (Window xwindow);
 
-
-/* style.c */
-
-void
-update_style (GtkWidget *widget);
-
-void
-style_changed (GtkWidget *widget, void *user_data /* PangoContext */);
-
 /* settings.c */
 
 void
