@@ -2004,17 +2004,6 @@ static const unsigned short _NET_WM_STATE_TOGGLE = 2;
 		    leaveShowDesktopMode (NULL);
 	    }
 	}
-	else if (event->xclient.message_type == Atoms::numberOfDesktops)
-	{
-	    if (event->xclient.window == privateScreen.rootWindow())
-	    {
-		CompOption::Value value;
-
-		value.set ((int) event->xclient.data.l[0]);
-
-		setOptionForPlugin ("core", "number_of_desktops", value);
-	    }
-	}
 	else if (event->xclient.message_type == Atoms::currentDesktop)
 	{
 	    if (event->xclient.window == privateScreen.rootWindow())
@@ -2344,6 +2333,8 @@ static const unsigned short _NET_WM_STATE_TOGGLE = 2;
     case FocusOut:
 	if (event->xfocus.mode == NotifyUngrab)
 	    privateScreen.eventManager.ungrabNotified ();
+	else if (event->xfocus.mode == NotifyWhileGrabbed)
+	    privateScreen.eventManager.grabNotified ();
 	break;
     case EnterNotify:
 	if (event->xcrossing.root == privateScreen.rootWindow())
@@ -2362,18 +2353,21 @@ static const unsigned short _NET_WM_STATE_TOGGLE = 2;
 	    {
 		bool raise;
 		int  delay;
+		int  mask = CompWindowTypeDockMask;
 
 		raise = privateScreen.optionGetAutoraise ();
 		delay = privateScreen.optionGetAutoraiseDelay ();
 
+		if (!privateScreen.optionGetFocusDesktop ())
+		    mask = mask | CompWindowTypeDesktopMask;
+
 		if (autoRaiseTimer_.active () &&
 		    autoRaiseWindow_ != w->id ())
 		{
 		    autoRaiseTimer_.stop ();
 		}
 
-		if (w->type () & ~(CompWindowTypeDockMask |
-				   CompWindowTypeDesktopMask))
+		if (w->type () & ~mask)
 		{
 		    w->moveInputFocusTo ();
 
